# set_vscode_theme { #vscodenb.set_vscode_theme }

```python
vscodenb.set_vscode_theme(
    mode=None,
    style='grid',
    frame=False,
    cmap=None,
    figsize=(5, 3.7),
    font_scale=1.0,
)
```

Set the default theme for the graph plotter.
The theme can be either 'dark' or 'light'. The default theme is autodetected.
NOTEBOOK_THEME environment variable can be used to override the theme.

## Parameters {.doc-section .doc-section-parameters}

<code>[**mode**]{.parameter-name} [:]{.parameter-annotation-sep} [[str](`str`)]{.parameter-annotation} [ = ]{.parameter-default-sep} [None]{.parameter-default}</code>

:   'dark' or 'light' to force a specific theme. If None, autodetected.

<code>[**style**]{.parameter-name} [:]{.parameter-annotation-sep} [[str](`str`)]{.parameter-annotation} [ = ]{.parameter-default-sep} [\'grid\']{.parameter-default}</code>

:   'grid' for grid style, 'ticks' for ticks style.

<code>[**frame**]{.parameter-name} [:]{.parameter-annotation-sep} [[bool](`bool`)]{.parameter-annotation} [ = ]{.parameter-default-sep} [False]{.parameter-default}</code>

:   Whether to show frame around plots.

<code>[**cmap**]{.parameter-name} [:]{.parameter-annotation-sep} [[Colormap](`Colormap`)]{.parameter-annotation} [ = ]{.parameter-default-sep} [None]{.parameter-default}</code>

:   Matplotlib colormap to use for plots.

<code>[**figsize**]{.parameter-name} [:]{.parameter-annotation-sep} [[tuple](`tuple`)]{.parameter-annotation} [ = ]{.parameter-default-sep} [(5, 3.7)]{.parameter-default}</code>

:   Default figure size.

<code>[**font_scale**]{.parameter-name} [:]{.parameter-annotation-sep} [[float](`float`)]{.parameter-annotation} [ = ]{.parameter-default-sep} [1.0]{.parameter-default}</code>

:   Scale factor for fonts.